@@ -3,8 +3,8 @@
 ;; This is free and unencumbered software released into the public domain.
 
 ;; Author: Christopher Wellons <wellons@nullprogram.com>
-;; Package-Version: 20241202.22
-;; Package-Revision: a39fb78e34ee
+;; Package-Version: 20260125.1850
+;; Package-Revision: 66cfe43dfc61
 ;; URL: https://github.com/skeeto/elfeed
 
 ;;; Commentary:
@@ -657,11 +657,10 @@ saved to your customization file."
 
 (provide 'elfeed)
 
-(cl-eval-when (load eval)
+(unless nil
   ;; run-time only, so don't load when compiling other files
-  (unless byte-compile-root-dir
-    (require 'elfeed-csv)
-    (require 'elfeed-show)
-    (require 'elfeed-search)))
+  (require 'elfeed-csv)
+  (require 'elfeed-show)
+  (require 'elfeed-search))
 
 ;;; elfeed.el ends here
